/*
 * Copyright (c) 2008 appspy.org, Contributors.
 * Licensed under the Apache License, Version 2.0 (the "License"); 
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 
 * Unless required by applicable law or agreed to in writing, software distributed under the 
 * License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, 
 * either express or implied. See the License for the specific language governing permissions 
 * and limitations under the License. */

package org.appspy.client.collector;

import java.net.URL;
import java.util.Properties;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.appspy.client.common.Collector;
import org.appspy.client.common.config.CollectorConfig;
import org.springframework.beans.factory.config.PropertyPlaceholderConfigurer;
import org.springframework.beans.factory.xml.XmlBeanDefinitionReader;
import org.springframework.context.ConfigurableApplicationContext;
import org.springframework.context.support.GenericApplicationContext;
import org.springframework.core.io.UrlResource;

/**
 * @author Olivier HEDIN / olivier@appspy.org
 */
public class CollectorFactoryUtils {
	
	protected static Log sLog = LogFactory.getLog(CollectorFactoryUtils.class);

	public static ConfigurableApplicationContext createApplicationContext(Properties propertiesConfig, URL collectorConfigURL)
	{
		 GenericApplicationContext ctx = new GenericApplicationContext();
		 ctx.setClassLoader(CollectorFactoryUtils.class.getClassLoader());
		 PropertyPlaceholderConfigurer ppc = new PropertyPlaceholderConfigurer();
		 ppc.setProperties(propertiesConfig);
		 ctx.addBeanFactoryPostProcessor(ppc);
		 XmlBeanDefinitionReader xmlReader = new XmlBeanDefinitionReader(ctx);
		 xmlReader.loadBeanDefinitions(new UrlResource(collectorConfigURL));
		 ctx.refresh();
		 
		 CollectorImpl collector = (CollectorImpl) ctx.getBean("collector");
		 CollectorConfig collectorConfig = new CollectorConfig(propertiesConfig);
		 collector.init(collectorConfig);
		 
		 return ctx;
	}
	
	public static Collector getCollector(Properties propertiesConfig, URL collectorConfigURL) throws Exception
	{
		Collector collector = null;
		
		ConfigurableApplicationContext appCtx = createApplicationContext(propertiesConfig, collectorConfigURL);
		
		collector = (Collector) appCtx.getBean("collector");
		
		return collector;
	}
}
